from flask import request, make_response, Blueprint
from flask_socketio import emit
from flasgger import swag_from
from utils.decorators import login_required
from utils.responses import success_ok
from const import APPLICATION_CODE
from dgapi import DGAPI


auth = Blueprint('authentication', __name__)


@auth.route('/one_authentication', methods=['GET'])
@swag_from('./docs/one_authentication.yml')
def one_authentication():
    res = DGAPI.post("one_authentication", {"application_code": APPLICATION_CODE})
    return make_response(res.text, res.status_code)


@auth.route('/force_app_update', methods=['POST'])
@login_required
def force_app_update():
    emit("OnForceUpdate", request.json, broadcast=True, namespace="/")
    return success_ok()


@auth.route('/logout', methods=['GET'])
@login_required
@swag_from('./docs/logout.yml')
def logout():
    res = DGAPI.get("logout")
    return make_response(res.text, res.status_code)


@auth.route('/is_authorized', methods=['GET'])
@login_required
@swag_from('./docs/is_authorized.yml')
def is_authorized():
    return success_ok()



from os import path
from paramiko import SSHClient, AutoAddPolicy
from sys import argv

SHOST, SUSER, SPWD, BRANCH = argv[1:5]
DIR_DEPLOY = path.basename(path.dirname(path.realpath(__file__)))  # directorio root api
with SSHClient() as ssh:
    ssh.set_missing_host_key_policy(AutoAddPolicy())
    if 'test' in argv:
        command = 'pwd;'
    else:
        command = """
        cd "$(find /home/itadmin/applications -type d -name %s)";
        git checkout %s;
        pwd;
        git branch;
        git pull;
        git status;
        apiServ="$(basename "$(find ../ -type f -name *.service | head -1)")";
        systemctl restart $apiServ;
        systemctl status $apiServ;
        """ % (DIR_DEPLOY, BRANCH)
    ssh.connect(SHOST, 22, SUSER, SPWD)
    stdin, stdout, stderr = ssh.exec_command(command)
    info_out = str(stdout.read().decode('utf8'))
    info_err = str(stderr.read().decode('utf8'))
    print(info_out, info_err)



from argparse import ArgumentParser
from dgx import create_app, delete_app

parser = ArgumentParser(description='Dealergeek Generator API Express', usage='DGX', )

parser.add_argument(
    "-d",
    "--delete",
    default=None,
    required=False,
    help="Delete the project",
)
parser.add_argument(
    "-c",
    "--create",
    default=None,
    required=False,
    help="Create a new api",
)


def main():
    """
    Evalua los parametros
    """
    args = parser.parse_args()
    if args.create:
        create_app(args.create)
    elif args.delete:
        delete_app(args.delete)
    else:
        parser.print_help()


if __name__ == "__main__":
    main()



from pymongo import MongoClient
from const import MONGO_CONN


class MongoCon:

    def __init__(self, conf=None):
        conf = conf or MONGO_CONN
        self.conf = conf
        self.cnx = MongoClient(conf['host'], conf['port'])
        self.db().authenticate(conf['user'], conf['password'])

    def db(self):
        """Devuelve la base de datos"""
        return self.cnx[self.conf['database']]

    def __enter__(self):
        return self.db()

    def __exit__(self, type, value, tb):
        self.cnx.close()
